summaryrefslogtreecommitdiffstats
path: root/kgoldrunner/src/kgrgame.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:42:31 +0000
commit576eb4299a00bc053db35414406f46372a0f70f2 (patch)
tree4c030922d533821db464af566188e7d40cc8848c /kgoldrunner/src/kgrgame.h
parent0718336b6017d1a4fc1d626544180a5a2a29ddec (diff)
downloadtdegames-576eb4299a00bc053db35414406f46372a0f70f2.tar.gz
tdegames-576eb4299a00bc053db35414406f46372a0f70f2.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1157643 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kgoldrunner/src/kgrgame.h')
-rw-r--r--kgoldrunner/src/kgrgame.h68
1 files changed, 34 insertions, 34 deletions
diff --git a/kgoldrunner/src/kgrgame.h b/kgoldrunner/src/kgrgame.h
index 86144ef6..18003e3c 100644
--- a/kgoldrunner/src/kgrgame.h
+++ b/kgoldrunner/src/kgrgame.h
@@ -12,29 +12,29 @@
// Macros to smooth out the differences between Qt 1 and Qt 2 classes.
//
// "myStr" converts a QString object to a C language "char*" character string.
// "myChar" extracts a C language character (type "char") from a QString object.
// "endData" checks for an end-of-file condition.
//
#define myStr latin1
#define myChar(i) at((i)).latin1()
#define endData atEnd
-#include <qobject.h>
+#include <tqobject.h>
#ifdef QT3
-#include <qptrlist.h>
+#include <tqptrlist.h>
#else
-#include <qlist.h>
+#include <tqlist.h>
#endif
-#include <qstring.h>
+#include <tqstring.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qdatastream.h>
+#include <tqdir.h>
+#include <tqfile.h>
+#include <tqtextstream.h>
+#include <tqdatastream.h>
-#include <qcolor.h>
+#include <tqcolor.h>
/**
Sets up games and levels in KGoldrunner and controls the play.
@@ -51,7 +51,7 @@ class KGrGame : public QObject
{
Q_OBJECT
public:
- KGrGame (KGrCanvas * theView, QString theSystemDir, QString theUserDir);
+ KGrGame (KGrCanvas * theView, TQString theSystemDir, TQString theUserDir);
~KGrGame();
bool initCollections();
@@ -71,7 +71,7 @@ public:
void setEditObj (char newEditObj); // Set object for editor to paint.
- QString getFilePath (Owner o, KGrCollection * colln, int lev);
+ TQString getFilePath (Owner o, KGrCollection * colln, int lev);
public slots:
void startLevelOne(); // Start any game from level 1.
@@ -117,7 +117,7 @@ private slots:
private:
void setBlankLevel (bool playable);
int loadLevel (int levelNo);
- bool openLevelFile (int levelNo, QFile & openlevel);
+ bool openLevelFile (int levelNo, TQFile & openlevel);
void changeObject (unsigned char kind, int i, int j);
void createObject (KGrObject *o, char picType, int x, int y);
void setTimings ();
@@ -155,7 +155,7 @@ private:
int startI, startJ; // The hero's starting position.
#ifdef QT3
- QPtrList<KGrEnemy> enemies; // The list of enemies.
+ TQPtrList<KGrEnemy> enemies; // The list of enemies.
#else
QList<KGrEnemy> enemies; // The list of enemies.
#endif
@@ -170,8 +170,8 @@ private:
bool modalFreeze; // Stop game during dialog.
bool messageFreeze; // Stop game during message.
- QTimer * mouseSampler; // Timer for mouse tracking.
- QTimer * dyingTimer; // For pause when the hero dies.
+ TQTimer * mouseSampler; // Timer for mouse tracking.
+ TQTimer * dyingTimer; // For pause when the hero dies.
int lgHighlight; // Row selected in "loadGame()".
@@ -230,10 +230,10 @@ private:
bool ownerOK (Owner o);
// Pixmaps for repainting objects as they are edited.
- QPixmap digpix[10];
- QPixmap brickbg, fbrickbg;
- QPixmap freebg, nuggetbg, polebg, betonbg, ladderbg, hladderbg;
- QPixmap edherobg, edenemybg;
+ TQPixmap digpix[10];
+ TQPixmap brickbg, fbrickbg;
+ TQPixmap freebg, nuggetbg, polebg, betonbg, ladderbg, hladderbg;
+ TQPixmap edherobg, edenemybg;
private slots:
void doEdit(int); // For mouse-click when in edit-mode.
@@ -247,7 +247,7 @@ private:
// Note that a collection of KGoldrunner levels is the same thing as a "game".
#ifdef QT3
- QPtrList<KGrCollection> collections; // List of ALL collections.
+ TQPtrList<KGrCollection> collections; // List of ALL collections.
#else
QList<KGrCollection> collections; // List of ALL collections.
#endif
@@ -264,7 +264,7 @@ private:
/********************** WORD-WRAPPED MESSAGE BOX ************************/
/******************************************************************************/
- void myMessage (QWidget * parent, QString title, QString contents);
+ void myMessage (TQWidget * parent, TQString title, TQString contents);
};
/******************************************************************************/
@@ -274,18 +274,18 @@ private:
class KGrThumbNail : public QFrame
{
public:
- KGrThumbNail (QWidget *parent = 0, const char *name = 0);
- void setFilePath (QString &, QLabel *); // Set filepath and name field.
+ KGrThumbNail (TQWidget *parent = 0, const char *name = 0);
+ void setFilePath (TQString &, TQLabel *); // Set filepath and name field.
- static QColor backgroundColor;
- static QColor brickColor;
- static QColor ladderColor;
- static QColor poleColor;
+ static TQColor backgroundColor;
+ static TQColor brickColor;
+ static TQColor ladderColor;
+ static TQColor poleColor;
protected:
- void drawContents (QPainter *); // Draw a preview of a level.
- QString filePath;
- QLabel * lName;
+ void drawContents (TQPainter *); // Draw a preview of a level.
+ TQString filePath;
+ TQLabel * lName;
};
/******************************************************************************/
@@ -296,8 +296,8 @@ protected:
class KGrCollection
{
public:
- KGrCollection (Owner o, const QString & n, const QString & p,
- const char s, int nl, const QString & a);
+ KGrCollection (Owner o, const TQString & n, const TQString & p,
+ const char s, int nl, const TQString & a);
Owner owner; // Collection owner: "System" or "User".
QString name; // Collection name.
QString prefix; // Collection's filename prefix.
@@ -12,29 +12,29 @@
// Macros to smooth out the differences between Qt 1 and Qt 2 classes.
//
-// "myStr" converts a QString object to a C language "char*" character string.
-// "myChar" extracts a C language character (type "char") from a QString object.
+// "myStr" converts a TQString object to a C language "char*" character string.
+// "myChar" extracts a C language character (type "char") from a TQString object.
// "endData" checks for an end-of-file condition.
//